@@ -136,6 +136,23 @@ sub cleartmpdir {
 }
 
 
+=head3 _touch
+
+Touch a file
+
+=cut
+
+sub _touch {
+    my ( $file ) = @_;
+    my $now = time;
+    local (*TMP);
+
+    utime ($now, $now, $file)
+                || open (TMP, ">>$file")
+                || warn ("Couldn't touch file: $!\n");
+} 
+
+
 =head2 touch_files
 
 "Touch" some files. Takes: directory path and list of files to "touch" in
@@ -149,11 +166,9 @@ sub touch_files {
 
     my $count = @file_list;
     try {
-        use File::Touch;
-        File::Touch::touch( 
-            map { File::Spec->catfile( $dirspec, $_ ); }
-            @file_list 
-        );
+        foreach my $file ( map { File::Spec->catfile( $dirspec, $_ ); } @file_list ) {
+            _touch( $file );
+        }
     }
     catch {
         my $errmsg = $_;
